@@ -1,4 +1,5 @@
 import os
+import warnings
 from collections import Counter, defaultdict
 from copy import copy
 from numbers import Integral
@@ -22,7 +23,6 @@ from Orange.data import (
 )
 from Orange.preprocess.transformation import Identity
 from Orange.data.util import get_unique_names
-from orangecontrib.text.vectorization import BowVectorizer
 
 try:
     from orangewidget.utils.signals import summarize, PartialSummary
@@ -86,7 +86,6 @@ class Corpus(Table):
         self.text_features = []    # list of text features for mining
         self._tokens = None
         self._dictionary = None
-        self._ngrams_corpus = None
         self.ngram_range = (1, 1)
         self.attributes = {}
         self._pos_tags = None
@@ -459,16 +458,6 @@ class Corpus(Table):
                 for n in range(self.ngram_range[0], self.ngram_range[1]+1))))
                 for doc in data)
 
-    @property
-    def ngrams_corpus(self):
-        if self._ngrams_corpus is None:
-            return BowVectorizer().transform(self).ngrams_corpus
-        return self._ngrams_corpus
-
-    @ngrams_corpus.setter
-    def ngrams_corpus(self, value):
-        self._ngrams_corpus = value
-
     @property
     def ngrams(self):
         """generator: Ngram representations of documents."""
@@ -487,7 +476,6 @@ class Corpus(Table):
         c.used_preprocessor = self.used_preprocessor
         c._titles = self._titles
         c._pp_documents = self._pp_documents
-        c._ngrams_corpus = self._ngrams_corpus
         return c
 
     @staticmethod
@@ -651,13 +639,16 @@ class Corpus(Table):
             new.ngram_range = orig.ngram_range
             new.attributes = orig.attributes
             new.used_preprocessor = orig.used_preprocessor
-            if orig._ngrams_corpus is not None:
-                new.ngrams_corpus = orig._ngrams_corpus[key]
         else:  # orig is not Corpus
             new._set_unique_titles()
             new._infer_text_features()
 
     def __eq__(self, other):
+        warnings.warn(
+            "Corpus's __eq__  is deprecated and will be removed in Orange3-text"
+            "1.11. Equality operator will return True only for the same objects.",
+            FutureWarning
+        )
         def arrays_equal(a, b):
             if sp.issparse(a) != sp.issparse(b):
                 return False
