@@ -2,7 +2,6 @@ import numpy as np
 
 from Orange.data.util import SharedComputeValue
 from Orange.util import dummy_callback
-from orangecontrib.text.util import Sparse2CorpusSliceable
 
 
 class BaseVectorizer:
@@ -44,7 +43,6 @@ class BaseVectorizer:
             sparse=True,
             rename_existing=True
         )
-        corpus.ngrams_corpus = Sparse2CorpusSliceable(X.T)
         return corpus
 
 
